@@ -1,7 +1,7 @@
 package App::ListOrgAnniversaries;
 
-our $DATE = '2015-03-15'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $DATE = '2015-03-28'; # DATE
+our $VERSION = '0.26'; # VERSION
 
 use 5.010;
 use strict;
@@ -91,7 +91,7 @@ sub _process_hl {
         my $date_ny = $date->clone; $date_ny->add(years => $y+1);
       DATE:
         for my $d ($date_ly, $date_ty, $date_ny) {
-            my $days = int(($d->epoch - $today->epoch)/86400);
+            my $days = ($d < $today ? -1:1) * $d->delta_days($today)->in_units('days');
             next if defined($args->{due_in}) &&
                 $days > $args->{due_in};
             next if defined($args->{max_overdue}) &&
@@ -203,9 +203,7 @@ _
         },
         today => {
             summary => 'Assume today\'s date',
-            schema  => [any => {
-                of => ['int', [obj => {isa=>'DateTime'}]],
-            }],
+            schema  => [obj => isa=>'DateTime'],
             description => <<'_',
 
 You can provide Unix timestamp or DateTime object. If you provide a DateTime
@@ -243,15 +241,8 @@ sub list_org_anniversaries {
     my $f     = $args{field_pattern} // '';
     return [400, "Invalid field_pattern: $@"] unless eval { $f = qr/$f/i };
     $args{field_pattern} = $f;
-    if ($args{today}) {
-        if (ref($args{today})) {
-            $today = $args{today};
-        } else {
-            $today = DateTime->from_epoch(epoch=>$args{today}, time_zone=>$tz);
-        }
-    } else {
-        $today = DateTime->today(time_zone => $tz);
-    }
+
+    $today = $args{today} // DateTime->today(time_zone => $tz);
 
     $yest  = $today->clone->add(days => -1);
 
@@ -302,7 +293,7 @@ App::ListOrgAnniversaries - List all anniversaries in Org files
 
 =head1 VERSION
 
-This document describes version 0.25 of App::ListOrgAnniversaries (from Perl distribution App-OrgUtils), released on 2015-03-15.
+This document describes version 0.26 of App::ListOrgAnniversaries (from Perl distribution App-OrgUtils), released on 2015-03-28.
 
 =head1 SYNOPSIS
 
@@ -392,7 +383,7 @@ Will be passed to parser's options.
 
 If not set, TZ environment variable will be picked as default.
 
-=item * B<today> => I<int|obj>
+=item * B<today> => I<obj>
 
 Assume today's date.
 
