@@ -1,7 +1,7 @@
 package App::ListOrgHeadlines;
 
-our $DATE = '2015-03-15'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $DATE = '2015-03-28'; # DATE
+our $VERSION = '0.26'; # VERSION
 
 use 5.010001;
 use strict;
@@ -83,7 +83,7 @@ sub _process_hl {
 
     my $ats = $hl->get_active_timestamp;
     my $days;
-    $days = int(($ats->datetime->epoch - $today->epoch)/86400)
+    $days = ($ats->datetime < $today ? -1:1) * $ats->datetime->delta_days($today)->in_units('days')
         if $ats;
     if (exists $args->{due_in}) {
         return unless $ats;
@@ -298,9 +298,7 @@ If not set, TZ environment variable will be picked as default.
 _
         },
         today => {
-            schema => ['any' => {
-                of => ['int', [obj => {isa=>'DateTime'}]],
-            }],
+            schema => [obj => isa=>'DateTime'],
             summary => 'Assume today\'s date',
             description => <<'_',
 
@@ -338,15 +336,8 @@ sub list_org_headlines {
     my $sort  = $args{sort};
     my $tz    = $args{time_zone} // $ENV{TZ} // "UTC";
     my $files = $args{files};
-    if ($args{today}) {
-        if (ref($args{today})) {
-            $today = $args{today};
-        } else {
-            $today = DateTime->from_epoch(epoch=>$args{today}, time_zone=>$tz);
-        }
-    } else {
-        $today = DateTime->today(time_zone => $tz);
-    }
+
+    $today = $args{today} // DateTime->today(time_zone => $tz);
 
     $yest  = $today->clone->add(days => -1);
 
@@ -425,7 +416,7 @@ App::ListOrgHeadlines - List all headlines in all Org files
 
 =head1 VERSION
 
-This document describes version 0.25 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2015-03-15.
+This document describes version 0.26 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2015-03-28.
 
 =head1 SYNOPSIS
 
@@ -539,7 +530,7 @@ If not set, TZ environment variable will be picked as default.
 
 Only show headlines having this level as the maximum.
 
-=item * B<today> => I<int|obj>
+=item * B<today> => I<obj>
 
 Assume today's date.
 
